{% extends "wagtailadmin/base.html" %}

<ul class="breadcrumb">
  <li class="home"><a href="#" class="icon icon-home text-replace">Home</a></li>
  <li><a href="#">Various</a></li>
  <li><a href="#">Subpages</a></li>
  <li><a href="#">There is a max length of this many</a></li>
</ul>
